@@ -16,6 +16,7 @@
 from distutils import spawn
 import logging
 import os
+import six
 import socket
 
 import fixtures
@@ -40,6 +41,7 @@ from pifpaf.drivers import postgresql
 from pifpaf.drivers import rabbitmq
 from pifpaf.drivers import redis
 from pifpaf.drivers import s3rver
+from pifpaf.drivers import swift
 from pifpaf.drivers import zookeeper
 
 
@@ -252,6 +254,35 @@ class TestDrivers(testtools.TestCase):
         r = requests.get("http://localhost:%d/" % port)
         self.assertEqual(200, r.status_code)
 
+    @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
+                          "Gnocchi not found")
+    @testtools.skipUnless(six.PY2, "Swift does not support PY3")
+    @testtools.skipUnless(spawn.find_executable("swift-proxy-server"),
+                          "Swift not found")
+    def test_gnocchi_with_existing_swift(self):
+        self.useFixture(swift.SwiftDriver())
+        self.useFixture(gnocchi.GnocchiDriver(
+            storage_url=os.getenv("PIFPAF_URL")))
+        self.assertEqual("gnocchi://localhost:8041",
+                         os.getenv("PIFPAF_URL"))
+        r = requests.get("http://localhost:8041/")
+        self.assertEqual(200, r.status_code)
+
+    @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
+                          "Gnocchi not found")
+    @testtools.skipUnless(spawn.find_executable("s3rver"),
+                          "s3rver not found")
+    def test_gnocchi_with_existing_s3rver(self):
+        s3 = self.useFixture(s3rver.S3rverDriver(port=4569))
+        port = gnocchi.GnocchiDriver.DEFAULT_PORT + 12
+        self.useFixture(gnocchi.GnocchiDriver(
+            storage_url="s3://gnocchi:pass@localhost:%d" % s3.port,
+            port=port))
+        self.assertEqual("gnocchi://localhost:%d" % port,
+                         os.getenv("PIFPAF_URL"))
+        r = requests.get("http://localhost:%d/" % port)
+        self.assertEqual(200, r.status_code)
+
     @testtools.skipUnless(spawn.find_executable("gnocchi-api"),
                           "Gnocchi not found")
     @testtools.skipUnless(spawn.find_executable("ceph-mon"),
@@ -371,8 +402,14 @@ class TestDrivers(testtools.TestCase):
     def test_rabbitmq_cluster(self):
         a = self.useFixture(rabbitmq.RabbitMQDriver(cluster=True, port=12345))
         self.assertEqual(
-            "rabbit://%s:%s@localhost:%d,localhost:%d,localhost:%d//" % (
-                a.username, a.password, a.port, a.port + 1, a.port + 2),
+            "rabbit://%(user)s:%(pass)s@localhost:%(port1)d,"
+            "%(user)s:%(pass)s@localhost:%(port2)d,"
+            "%(user)s:%(pass)s@localhost:%(port3)d//" % {
+                "user": a.username,
+                "pass": a.password,
+                "port1": a.port,
+                "port2": a.port + 1,
+                "port3": a.port + 2},
             os.getenv("PIFPAF_URL"))
         self.assertEqual(a.nodename + "-1@localhost",
                          os.getenv("PIFPAF_RABBITMQ_NODENAME"))
@@ -387,6 +424,7 @@ class TestDrivers(testtools.TestCase):
         a.kill_node(a.nodename + "-2@localhost")
         a.stop_node(a.nodename + "-3@localhost")
         a.start_node(a.nodename + "-3@localhost")
+        a.start_node(a.nodename + "-2@localhost")
 
     @testtools.skipUnless(spawn.find_executable("couchdb"),
                           "CouchDB not found")
@@ -410,3 +448,21 @@ class TestDrivers(testtools.TestCase):
         self.assertEqual("PLAINTEXT", os.getenv("PIFPAF_KAFKA_PROTOCOL"))
         self.assertEqual("PLAINTEXT://localhost:54321",
                          os.getenv("PIFPAF_KAFKA_URL"))
+
+    @testtools.skipUnless(six.PY2, "Swift does not support PY3")
+    @testtools.skipUnless(spawn.find_executable("swift-proxy-server"),
+                          "Swift not found")
+    def test_swift(self):
+        a = self.useFixture(swift.SwiftDriver())
+        self.assertEqual("http://localhost:8080/auth/v1.0",
+                         os.getenv("PIFPAF_SWIFT_AUTH_URL"))
+        self.assertEqual(8080, a.port)
+        self.assertEqual("8080", os.getenv("PIFPAF_SWIFT_PORT"))
+        self.assertEqual("test:tester", os.getenv("PIFPAF_SWIFT_USERNAME"))
+        self.assertEqual("testing", os.getenv("PIFPAF_SWIFT_PASSWORD"))
+        self.assertEqual(
+            "swift://test%3Atester:testing@localhost:8080/auth/v1.0",
+            os.getenv("PIFPAF_SWIFT_URL"))
+        self.assertEqual(
+            "swift://test%3Atester:testing@localhost:8080/auth/v1.0",
+            os.getenv("PIFPAF_URL"))
